@@ -36,7 +36,9 @@ class Database(object):
         'id': (lambda: random.randint(1, 6)),
         'codi': (lambda: random.choice(["TT101", "TT102", "TT103", "Q78544", "Q03566", "Q03585", "N19627", "N19640", "N19685", "N18427", "N18440", "N18485", "G76211", "G40291", "013731", "G40111", "Q85544", "Q75958", "W29485", "Q85585", "N18542", "N18527", "N18540", "N18585", "009780", "013110"])),
         'descripcio': (lambda: "lorem ipsum algo no se que cosas latin"),
-
+        'cataleg': (lambda: random.randint(1, 32)),
+        'scs_codi': (lambda: "00089"),
+        'ics_desc': (lambda: "ABS AMPOSTA"),
     }
 
     def __init__(self, instance, schema, retry=None):
@@ -59,17 +61,21 @@ class Database(object):
 
     def generate_one(self, sql):
         sqlSelect = (sql[sql.find("select") + 6:sql.find("from")
-                         ].replace(" ", "").lower().split(","))
+                         ].replace(" ", "").replace("distinct", "").lower().split(","))
         data = {}
+        print(sqlSelect)
         if len(sqlSelect) > 0:
-            for key, value in Database.TEMPLATE.items():
-                if key in sqlSelect:
-                    if key == 'cod':
-                        info = random.choice(value)
+            for select in sqlSelect:
+                if select in Database.TEMPLATE:
+                    if select == 'cod':
+                        info = random.choice(Database.TEMPLATE[select])
                         data['cod'] = info[0]
                         data['val'] = info[1]()
                     else:
-                        data[key] = value()
+                        data[select] = Database.TEMPLATE[select]()
+                else:
+                    data[select] = random.randint(-50, -10)
+
         sorted_data = sorted(data.items(), key=lambda x: sqlSelect.index(x[0]))
         result = tuple(map(lambda d: d[1], sorted_data))
         return result
@@ -233,7 +239,8 @@ class Database(object):
             local='LOCAL' if self.local_infile else '',
             filename=filename,
             table=table,
-            partition='PARTITION ({})'.format(partition) if partition else '',
+            partition='PARTITION ({})'.format(
+                partition) if partition else '',
             charset=MARIA_CHARSET,
             delimiter=delimiter,
             endline=endline
